package com.kdanmobile.reader.screen.view

import android.content.Context
import android.support.v7.widget.LinearLayoutManager
import android.support.v7.widget.RecyclerView
import android.util.AttributeSet
import android.view.LayoutInflater
import android.widget.RelativeLayout
import com.kdanmobile.kmpdfkit.pdfcommon.Bookmark
import com.kdanmobile.reader.R
import com.kdanmobile.reader.ReaderViewModel
import com.kdanmobile.reader.screen.adapter.BookmarkAdapter
import com.kdanmobile.reader.screen.handler.BookmarkHandler
import com.kdanmobile.reader.screen.handler.PdfInfoHandler
import com.kdanmobile.reader.screen.handler.ThumbnailHandler
import com.kdanmobile.reader.widget.drag.OnRecyclerItemClickListener
import kotlinx.android.synthetic.main.view_bookmark.view.*
import java.util.*

class BookmarkView: RelativeLayout {
    private lateinit var adapter: BookmarkAdapter
    private lateinit var handler: ThumbnailHandler
    private var bookmarkItems: Array<Bookmark>? = null

    constructor(context: Context, viewModel: ReaderViewModel) : super(context) {
        initView(viewModel, viewModel, viewModel)
    }

    constructor(context: Context, attributeSet: AttributeSet, viewModel: ReaderViewModel) : super(context, attributeSet) {
        initView(viewModel, viewModel, viewModel)
    }

    constructor(context: Context, attributeSet: AttributeSet, defStyleAttr: Int, viewModel: ReaderViewModel) : super(context, attributeSet, defStyleAttr) {
        initView(viewModel, viewModel, viewModel)
    }

    private fun initView(pdfInfoHandler: PdfInfoHandler, thumbnailHandler: ThumbnailHandler, bookmarkHandler: BookmarkHandler) {
        LayoutInflater.from(context).inflate(R.layout.view_bookmark, this)
        val layoutManager = LinearLayoutManager(context)
        layoutManager.orientation = LinearLayoutManager.VERTICAL

        this.handler = thumbnailHandler

        id_km_bookmark_recycler.setHasFixedSize(true)
        id_km_bookmark_recycler.layoutManager = layoutManager
        id_km_bookmark_recycler.layoutManager = LinearLayoutManager(context)
        id_km_bookmark_recycler.addOnItemTouchListener(object : OnRecyclerItemClickListener(id_km_bookmark_recycler) {
            override fun onItemClick(viewHolder: RecyclerView.ViewHolder) {
                val bookmark = adapter.getItem(viewHolder.adapterPosition)
                if (null != bookmark) {
                    pdfInfoHandler.setCurrentPage(bookmark.pageNum)
                }
            }

            override fun onItemLongClick(viewHolder: RecyclerView.ViewHolder) {

            }
        })

        adapter = BookmarkAdapter(handler, bookmarkItems)
        id_km_bookmark_recycler.adapter = adapter
        onRefreshBookmarkDatas(bookmarkHandler.getBookmarks()!!)
    }


    private fun onRefreshBookmarkDatas(items: Array<Bookmark>) {
        try {
            this.bookmarkItems = items
            if (bookmarkItems?.isNotEmpty() != null) {
                Arrays.sort(bookmarkItems) { lhs, rhs -> if (lhs.pageNum > rhs.pageNum) 1 else -1 }
            }
            adapter.setOutlineItems(bookmarkItems)
        } catch (e: Exception) {
            e.printStackTrace()
        }

    }
}